@@ -1,7 +1,7 @@
-from ply import lex
-from ply.lex import TOKEN
 import re
 import os
+from ply import lex
+from ply.lex import TOKEN
 
 from .exceptions import ScriptError
 
@@ -149,7 +149,7 @@ class Lexer(object):
     NAME = r'(\d+\.)?(\.?_?[a-zA-Z]+(\-\w+)?\d*)+' + INDEXES
 
     def t_BOOLEAN(self, t):
-        r"(true|false)"
+        r"(true|false)(?=\s)"
         t.value = (t.value == 'true')
         return t
 
@@ -164,11 +164,11 @@ class Lexer(object):
         return t
 
     def t_KWARG(self, t):
-        r'(--[a-z\-]+)'
+        r'(--[a-z\_]+)'
         return t
 
     def t_EQ(self, t):
-        r'((==?)|((is\s)?equals?(\sto)?))'
+        r'((==?)|((is\s)?equals?(?=\s)(\sto)?))'
         t.value = "=="
         return t
 
@@ -192,7 +192,7 @@ class Lexer(object):
         return t
 
     def t_ISNT(self, t):
-        r"((is\snot)|isnt|not)"
+        r"((is\snot)|isnt|not)(?=\s)"
         t.value = 'isnot'
         return t
 
@@ -239,7 +239,7 @@ class Lexer(object):
         return t
 
     def t_ASCDESC(self, t):
-        r'(asc|desc)'
+        r'(asc|desc)(?=\s)'
         return t
 
     def t_FROM(self, t):
